@@ -5,12 +5,22 @@ module Byebug
   # Stop tracing a global variable.
   #
   class UntracevarCommand < Command
-    self.allow_in_post_mortem = false
-
-    def regexp
+    def self.regexp
       /^\s* untr(?:acevar)? (?:\s+ (\S+))? \s*$/x
     end
 
+    def self.description
+      <<-EOD
+        untr[acevar] <variable>
+
+        #{short_description}
+      EOD
+    end
+
+    def self.short_description
+      'Stops tracing a global variable'
+    end
+
     def execute
       var = @match[1]
       if global_variables.include?(:"#{var}")
@@ -20,19 +30,5 @@ module Byebug
         errmsg pr('trace.errors.not_global', var: var)
       end
     end
-
-    class << self
-      def names
-        %w(untracevar)
-      end
-
-      def description
-        prettify <<-EOD
-          untr[acevar] <variable>
-
-          Stop tracing global variable <variable>.
-        EOD
-      end
-    end
   end
 end
