@@ -7,7 +7,9 @@ module Byebug
   class RemoteInterface < Interface
     def initialize(socket)
       super()
-      @input, @output, @error = socket, socket, socket
+      @input = socket
+      @output = socket
+      @error = socket
     end
 
     def read_command(prompt)
@@ -28,7 +30,7 @@ module Byebug
       output.puts(prompt)
 
       result = input.gets
-      fail IOError unless result
+      raise IOError unless result
 
       result.chomp
     end
